from setuptools import setup

setup(name='udacityDistributionEMC',
      version='0.1',
      description='Gaussian & Binomial distributions',
      author='Eoghan McCarey',
      packages=['udacityDistributionEMC'],
      zip_safe=False)
